IF "%CONDA_BUILD%" == "" (
    call C:\b\abs_bdfy60mi5i\croot\hatch-jupyter-builder_1683742843850\work\build_env_setup.bat
)
REM ===== end generated header =====
C:\\b\\abs_bdfy60mi5i\\croot\\hatch-jupyter-builder_1683742843850\\_h_env\\python.exe -m pip install --no-deps --no-build-isolation . -vv